Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/m6rclib/__init__.py | 5 | 0 | 0 | 0 | 0 | 100%
src/m6rclib/embed_lexer.py | 29 | 0 | 0 | 6 | 0 | 100%
src/m6rclib/metaphor_ast_node.py | 45 | 0 | 8 | 6 | 0 | 100%
src/m6rclib/metaphor_formatters.py | 30 | 0 | 0 | 10 | 0 | 100%
src/m6rclib/metaphor_lexer.py | 91 | 0 | 0 | 42 | 0 | 100%
src/m6rclib/metaphor_parser.py | 228 | 0 | 0 | 100 | 0 | 100%
src/m6rclib/metaphor_token.py | 27 | 0 | 0 | 2 | 0 | 100%
Total | 455 | 0 | 8 | 166 | 0 | 100%

No items found using the specified filter.